import arcgisscripting
import os

def hullrectangles():
    gp = arcgisscripting.create(9.3)
    gp.OverWriteOutput = 1

    # Input FC
    inFC  = gp.GetParameterAsText(0)
    # Output FC
    outFC = gp.GetParameterAsText(1)
    
    createHullRectangles(gp, inFC, outFC) 

def createHullRectangles(gp, inFC, outFC):
    try:
        # Assign empty values to cursor and row objects
        #
        iCur, sRow, sCur, feat = None, None, None, None

        shapeName = gp.Describe(inFC).ShapeFieldName
        OIDName   = gp.Describe(inFC).OIDFieldName
        fieldList = []
        for field in gp.ListFields(inFC):
            if field.Name not in [shapeName, OIDName]:
                fieldList.append(field.Name)

        # Create the output feature class
        #
        outPath, outName = os.path.split(outFC)
        gp.CreateFeatureClass(outPath, outName, "Polygon", inFC, "SAME_AS_TEMPLATE", "SAME_AS_TEMPLATE", inFC)

        # Open an insert cursor for the new feature class
        #
        iCur = gp.InsertCursor(outFC)
        sCur = gp.SearchCursor(inFC)

        sRow = sCur.Next()

        # Create an array and point object needed to create features
        #
        lineArray = gp.CreateObject("Array")
        pt = gp.CreateObject("Point")

        while sRow:

            # Use hullrectangle property, and parse to create points for each
            #   corner of the output rectangle
            #
            shape = sRow.shape
            hullrectangleL = shape.hullrectangle.split(" ")
            for cnt in xrange(0,8,2):
                pt.x = hullrectangleL[cnt]
                pt.y = hullrectangleL[cnt+1]
                lineArray.add(pt)
            pt.x = hullrectangleL[0]
            pt.y = hullrectangleL[1]
            lineArray.Add(pt)

            polyGeometry = gp.createobject("geometry", "polygon", lineArray)

            # If the area of the geometry is zero, don't insert the feature
            #  
            if polyGeometry.area:
                feat = iCur.NewRow()
                feat.SetValue(shapeName, polyGeometry)

                # Walk through the fields to transfer other attributes across
                #
                for field in fieldList:
                    feat.SetValue(field, sRow.GetValue(field))
                iCur.InsertRow(feat)

            sRow = sCur.Next()            
            lineArray.RemoveAll()

    except Exception, err:
        print err.message
        gp.AddError(err.message)

    finally:
        if iCur:
            del iCur
        if sRow:
            del sRow
        if sCur:
            del sCur
        if feat:
            del feat

if __name__ == '__main__':
    hullrectangles()

